## BETA NOTICE: This is BETA software and may have bugs and can be removed without previous notice. It is intended for qualified beta testers only and must not be used in production systems.

## This client library is not design to be use directly, instead use ours [Pinterest Python SDK](https://github.com/pinterest/pinterest-python-sdk)

# Pinterest Generated Client
Pinterest's REST API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 5.6.0
- Package version: 0.1.3
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://developers.pinterest.com/](https://developers.pinterest.com/)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

#### Using HTTPS

```sh
pip install git+https://github.com/pinterest/pinterest-python-generated-api-client.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/pinterest/pinterest-python-generated-api-client.git`)

#### Using SSH

```sh
pip install git+ssh://github.com/pinterest/pinterest-python-generated-api-client.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/pinterest/pinterest-python-generated-api-client.git`)

Then import the package:
```python
import pinterest.generated.client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pinterest.generated.client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import pinterest.generated.client
from pprint import pprint
from pinterest.generated.client.api import ad_accounts_api
from pinterest.generated.client.model.ad_account import AdAccount
from pinterest.generated.client.model.ad_account_analytics_response import AdAccountAnalyticsResponse
from pinterest.generated.client.model.ad_account_create_request import AdAccountCreateRequest
from pinterest.generated.client.model.ads_analytics_create_async_request import AdsAnalyticsCreateAsyncRequest
from pinterest.generated.client.model.ads_analytics_create_async_response import AdsAnalyticsCreateAsyncResponse
from pinterest.generated.client.model.ads_analytics_get_async_response import AdsAnalyticsGetAsyncResponse
from pinterest.generated.client.model.ads_analytics_targeting_type import AdsAnalyticsTargetingType
from pinterest.generated.client.model.conversion_report_attribution_type import ConversionReportAttributionType
from pinterest.generated.client.model.error import Error
from pinterest.generated.client.model.granularity import Granularity
from pinterest.generated.client.model.metrics_response import MetricsResponse
from pinterest.generated.client.model.paginated import Paginated
# Defining the host is optional and defaults to https://api.pinterest.com/v5
# See configuration.py for a list of all supported configuration parameters.
configuration = pinterest.generated.client.Configuration(
    host = "https://api.pinterest.com/v5"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure OAuth2 access token for authorization: pinterest_oauth2
configuration = pinterest.generated.client.Configuration(
    host = "https://api.pinterest.com/v5"
)
configuration.access_token = 'YOUR_ACCESS_TOKEN'


# Enter a context with an instance of the API client
with pinterest.generated.client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ad_accounts_api.AdAccountsApi(api_client)
    ad_account_id = "4" # str | Unique identifier of an ad account.
    start_date = dateutil_parser('1970-01-01').date() # date | Metric report start date (UTC). Format: YYYY-MM-DD
    end_date = dateutil_parser('1970-01-01').date() # date | Metric report end date (UTC). Format: YYYY-MM-DD
    columns = [
        "SPEND_IN_DOLLAR",
    ] # [str] | Columns to retrieve, encoded as a comma-separated string. **NOTE**: Any metrics defined as MICRO_DOLLARS returns a value based on the advertiser profile's currency field. For USD,($1/1,000,000, or $0.000001 - one one-ten-thousandth of a cent). it's microdollars. Otherwise, it's in microunits of the advertiser's currency.<br/>For example, if the advertiser's currency is GBP (British pound sterling), all MICRO_DOLLARS fields will be in GBP microunits (1/1,000,000 British pound).<br/>If a column has no value, it may not be returned
    granularity = Granularity("DAY") # Granularity | TOTAL - metrics are aggregated over the specified date range.<br> DAY - metrics are broken down daily.<br> HOUR - metrics are broken down hourly.<br>WEEKLY - metrics are broken down weekly.<br>MONTHLY - metrics are broken down monthly
    click_window_days = 1 # int | Number of days to use as the conversion attribution window for a pin click action. Applies to Pinterest Tag conversion metrics. Prior conversion tags use their defined attribution windows. If not specified, defaults to `30` days. (optional) (default to 30)
    engagement_window_days = 30 # int | Number of days to use as the conversion attribution window for an engagement action. Engagements include saves, closeups, link clicks, and carousel card swipes. Applies to Pinterest Tag conversion metrics. Prior conversion tags use their defined attribution windows. If not specified, defaults to `30` days. (optional) (default to 30)
    view_window_days = 1 # int | Number of days to use as the conversion attribution window for a view action. Applies to Pinterest Tag conversion metrics. Prior conversion tags use their defined attribution windows. If not specified, defaults to `1` day. (optional) (default to 1)
    conversion_report_time = "TIME_OF_AD_ACTION" # str | The date by which the conversion metrics returned from this endpoint will be reported. There are two dates associated with a conversion event: the date that the user interacted with the ad, and the date that the user completed a conversion event. (optional) (default to "TIME_OF_AD_ACTION")

    try:
        # Get ad account analytics
        api_response = api_instance.ad_account_analytics(ad_account_id, start_date, end_date, columns, granularity, click_window_days=click_window_days, engagement_window_days=engagement_window_days, view_window_days=view_window_days, conversion_report_time=conversion_report_time)
        pprint(api_response)
    except pinterest.generated.client.ApiException as e:
        print("Exception when calling AdAccountsApi->ad_account_analytics: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.pinterest.com/v5*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdAccountsApi* | [**ad_account_analytics**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsApi.md#ad_account_analytics) | **GET** /ad_accounts/{ad_account_id}/analytics | Get ad account analytics
*AdAccountsApi* | [**ad_account_targeting_analytics_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsApi.md#ad_account_targeting_analytics_get) | **GET** /ad_accounts/{ad_account_id}/targeting_analytics | Get targeting analytics for an ad account
*AdAccountsApi* | [**ad_accounts_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsApi.md#ad_accounts_create) | **POST** /ad_accounts | Create ad account
*AdAccountsApi* | [**ad_accounts_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsApi.md#ad_accounts_get) | **GET** /ad_accounts/{ad_account_id} | Get ad account
*AdAccountsApi* | [**ad_accounts_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsApi.md#ad_accounts_list) | **GET** /ad_accounts | List ad accounts
*AdAccountsApi* | [**analytics_create_report**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsApi.md#analytics_create_report) | **POST** /ad_accounts/{ad_account_id}/reports | Create async request for an account analytics report
*AdAccountsApi* | [**analytics_get_report**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsApi.md#analytics_get_report) | **GET** /ad_accounts/{ad_account_id}/reports | Get the account analytics report created by the async call
*AdGroupsApi* | [**ad_groups_analytics**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupsApi.md#ad_groups_analytics) | **GET** /ad_accounts/{ad_account_id}/ad_groups/analytics | Get ad group analytics
*AdGroupsApi* | [**ad_groups_bid_floor_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupsApi.md#ad_groups_bid_floor_get) | **POST** /ad_accounts/{ad_account_id}/bid_floor | Get bid floors
*AdGroupsApi* | [**ad_groups_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupsApi.md#ad_groups_create) | **POST** /ad_accounts/{ad_account_id}/ad_groups | Create ad groups
*AdGroupsApi* | [**ad_groups_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupsApi.md#ad_groups_get) | **GET** /ad_accounts/{ad_account_id}/ad_groups/{ad_group_id} | Get ad group
*AdGroupsApi* | [**ad_groups_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupsApi.md#ad_groups_list) | **GET** /ad_accounts/{ad_account_id}/ad_groups | List ad groups
*AdGroupsApi* | [**ad_groups_targeting_analytics_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupsApi.md#ad_groups_targeting_analytics_get) | **GET** /ad_accounts/{ad_account_id}/ad_groups/targeting_analytics | Get targeting analytics for ad groups
*AdGroupsApi* | [**ad_groups_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupsApi.md#ad_groups_update) | **PATCH** /ad_accounts/{ad_account_id}/ad_groups | Update ad groups
*AdsApi* | [**ad_previews_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsApi.md#ad_previews_create) | **POST** /ad_accounts/{ad_account_id}/ad_previews | Create ad preview with pin or image
*AdsApi* | [**ad_targeting_analytics_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsApi.md#ad_targeting_analytics_get) | **GET** /ad_accounts/{ad_account_id}/ads/targeting_analytics | Get targeting analytics for ads
*AdsApi* | [**ads_analytics**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsApi.md#ads_analytics) | **GET** /ad_accounts/{ad_account_id}/ads/analytics | Get ad analytics
*AdsApi* | [**ads_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsApi.md#ads_create) | **POST** /ad_accounts/{ad_account_id}/ads | Create ads
*AdsApi* | [**ads_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsApi.md#ads_get) | **GET** /ad_accounts/{ad_account_id}/ads/{ad_id} | Get ad
*AdsApi* | [**ads_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsApi.md#ads_list) | **GET** /ad_accounts/{ad_account_id}/ads | List ads
*AdsApi* | [**ads_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsApi.md#ads_update) | **PATCH** /ad_accounts/{ad_account_id}/ads | Update ads
*AudiencesApi* | [**audiences_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudiencesApi.md#audiences_create) | **POST** /ad_accounts/{ad_account_id}/audiences | Create audience
*AudiencesApi* | [**audiences_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudiencesApi.md#audiences_get) | **GET** /ad_accounts/{ad_account_id}/audiences/{audience_id} | Get audience
*AudiencesApi* | [**audiences_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudiencesApi.md#audiences_list) | **GET** /ad_accounts/{ad_account_id}/audiences | List audiences
*AudiencesApi* | [**audiences_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudiencesApi.md#audiences_update) | **PATCH** /ad_accounts/{ad_account_id}/audiences/{audience_id} | Update audience
*BoardsApi* | [**board_sections_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#board_sections_create) | **POST** /boards/{board_id}/sections | Create board section
*BoardsApi* | [**board_sections_delete**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#board_sections_delete) | **DELETE** /boards/{board_id}/sections/{section_id} | Delete board section
*BoardsApi* | [**board_sections_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#board_sections_list) | **GET** /boards/{board_id}/sections | List board sections
*BoardsApi* | [**board_sections_list_pins**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#board_sections_list_pins) | **GET** /boards/{board_id}/sections/{section_id}/pins | List Pins on board section
*BoardsApi* | [**board_sections_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#board_sections_update) | **PATCH** /boards/{board_id}/sections/{section_id} | Update board section
*BoardsApi* | [**boards_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#boards_create) | **POST** /boards | Create board
*BoardsApi* | [**boards_delete**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#boards_delete) | **DELETE** /boards/{board_id} | Delete board
*BoardsApi* | [**boards_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#boards_get) | **GET** /boards/{board_id} | Get board
*BoardsApi* | [**boards_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#boards_list) | **GET** /boards | List boards
*BoardsApi* | [**boards_list_pins**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#boards_list_pins) | **GET** /boards/{board_id}/pins | List Pins on board
*BoardsApi* | [**boards_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardsApi.md#boards_update) | **PATCH** /boards/{board_id} | Update board
*BulkApi* | [**bulk_download_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkApi.md#bulk_download_create) | **POST** /ad_accounts/{ad_account_id}/bulk/download | Get advertiser entities in bulk
*BulkApi* | [**bulk_request_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkApi.md#bulk_request_get) | **GET** /ad_accounts/{ad_account_id}/bulk/{bulk_request_id} | Download advertiser entities in bulk
*BulkApi* | [**bulk_upsert_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkApi.md#bulk_upsert_create) | **POST** /ad_accounts/{ad_account_id}/bulk/upsert | Create/update ad entities in bulk
*CampaignsApi* | [**campaign_targeting_analytics_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignsApi.md#campaign_targeting_analytics_get) | **GET** /ad_accounts/{ad_account_id}/campaigns/targeting_analytics | Get targeting analytics for campaigns
*CampaignsApi* | [**campaigns_analytics**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignsApi.md#campaigns_analytics) | **GET** /ad_accounts/{ad_account_id}/campaigns/analytics | Get campaign analytics
*CampaignsApi* | [**campaigns_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignsApi.md#campaigns_create) | **POST** /ad_accounts/{ad_account_id}/campaigns | Create campaigns
*CampaignsApi* | [**campaigns_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignsApi.md#campaigns_get) | **GET** /ad_accounts/{ad_account_id}/campaigns/{campaign_id} | Get campaign
*CampaignsApi* | [**campaigns_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignsApi.md#campaigns_list) | **GET** /ad_accounts/{ad_account_id}/campaigns | List campaigns
*CampaignsApi* | [**campaigns_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignsApi.md#campaigns_update) | **PATCH** /ad_accounts/{ad_account_id}/campaigns | Update campaigns
*CatalogsApi* | [**catalogs_product_group_pins_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#catalogs_product_group_pins_list) | **GET** /catalogs/product_groups/{product_group_id}/products | List products
*CatalogsApi* | [**catalogs_product_groups_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#catalogs_product_groups_create) | **POST** /catalogs/product_groups | Create product group
*CatalogsApi* | [**catalogs_product_groups_delete**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#catalogs_product_groups_delete) | **DELETE** /catalogs/product_groups/{product_group_id} | Delete product group
*CatalogsApi* | [**catalogs_product_groups_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#catalogs_product_groups_get) | **GET** /catalogs/product_groups/{product_group_id} | Get product group
*CatalogsApi* | [**catalogs_product_groups_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#catalogs_product_groups_list) | **GET** /catalogs/product_groups | List product groups
*CatalogsApi* | [**catalogs_product_groups_product_counts_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#catalogs_product_groups_product_counts_get) | **GET** /catalogs/product_groups/{product_group_id}/product_counts | Get product counts
*CatalogsApi* | [**catalogs_product_groups_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#catalogs_product_groups_update) | **PATCH** /catalogs/product_groups/{product_group_id} | Update product group
*CatalogsApi* | [**feed_processing_results_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#feed_processing_results_list) | **GET** /catalogs/feeds/{feed_id}/processing_results | List processing results for a given feed
*CatalogsApi* | [**feeds_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#feeds_create) | **POST** /catalogs/feeds | Create feed
*CatalogsApi* | [**feeds_delete**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#feeds_delete) | **DELETE** /catalogs/feeds/{feed_id} | Delete feed
*CatalogsApi* | [**feeds_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#feeds_get) | **GET** /catalogs/feeds/{feed_id} | Get feed
*CatalogsApi* | [**feeds_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#feeds_list) | **GET** /catalogs/feeds | List feeds
*CatalogsApi* | [**feeds_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#feeds_update) | **PATCH** /catalogs/feeds/{feed_id} | Update feed
*CatalogsApi* | [**items_batch_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#items_batch_get) | **GET** /catalogs/items/batch/{batch_id} | Get catalogs items batch
*CatalogsApi* | [**items_batch_post**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#items_batch_post) | **POST** /catalogs/items/batch | Operate on item batch
*CatalogsApi* | [**items_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#items_get) | **GET** /catalogs/items | Get catalogs items
*CatalogsApi* | [**items_issues_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#items_issues_list) | **GET** /catalogs/processing_results/{processing_result_id}/item_issues | List item issues for a given processing result
*CatalogsApi* | [**products_by_product_group_filter_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsApi.md#products_by_product_group_filter_list) | **POST** /catalogs/products/get_by_product_group_filters | List filtered products
*ConversionEventsApi* | [**events_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEventsApi.md#events_create) | **POST** /ad_accounts/{ad_account_id}/events | Send conversion events to the Pinterest API for Conversions
*CustomerListsApi* | [**customer_lists_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomerListsApi.md#customer_lists_create) | **POST** /ad_accounts/{ad_account_id}/customer_lists | Create customer lists
*CustomerListsApi* | [**customer_lists_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomerListsApi.md#customer_lists_get) | **GET** /ad_accounts/{ad_account_id}/customer_lists/{customer_list_id} | Get customer list
*CustomerListsApi* | [**customer_lists_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomerListsApi.md#customer_lists_list) | **GET** /ad_accounts/{ad_account_id}/customer_lists | Get customer lists
*CustomerListsApi* | [**customer_lists_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomerListsApi.md#customer_lists_update) | **PATCH** /ad_accounts/{ad_account_id}/customer_lists/{customer_list_id} | Update customer list
*KeywordsApi* | [**country_keywords_metrics_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordsApi.md#country_keywords_metrics_get) | **GET** /ad_accounts/{ad_account_id}/keywords/metrics | Get country&#39;s keyword metrics
*KeywordsApi* | [**keywords_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordsApi.md#keywords_create) | **POST** /ad_accounts/{ad_account_id}/keywords | Create keywords
*KeywordsApi* | [**keywords_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordsApi.md#keywords_get) | **GET** /ad_accounts/{ad_account_id}/keywords | Get keywords
*KeywordsApi* | [**keywords_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordsApi.md#keywords_update) | **PATCH** /ad_accounts/{ad_account_id}/keywords | Update keywords
*MediaApi* | [**media_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaApi.md#media_create) | **POST** /media | Register media upload
*MediaApi* | [**media_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaApi.md#media_get) | **GET** /media/{media_id} | Get media upload details
*MediaApi* | [**media_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaApi.md#media_list) | **GET** /media | List media uploads
*OauthApi* | [**oauth_token**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthApi.md#oauth_token) | **POST** /oauth/token | Generate OAuth access token
*PinsApi* | [**pins_analytics**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinsApi.md#pins_analytics) | **GET** /pins/{pin_id}/analytics | Get Pin analytics
*PinsApi* | [**pins_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinsApi.md#pins_create) | **POST** /pins | Create Pin
*PinsApi* | [**pins_delete**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinsApi.md#pins_delete) | **DELETE** /pins/{pin_id} | Delete Pin
*PinsApi* | [**pins_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinsApi.md#pins_get) | **GET** /pins/{pin_id} | Get Pin
*PinsApi* | [**pins_save**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinsApi.md#pins_save) | **POST** /pins/{pin_id}/save | Save pin
*ProductGroupPromotionsApi* | [**product_group_promotion_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionsApi.md#product_group_promotion_get) | **GET** /ad_accounts/{ad_account_id}/product_group_promotions/{product_group_promotion_id} | Get a product group promotion by id
*ProductGroupPromotionsApi* | [**product_group_promotions_create**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionsApi.md#product_group_promotions_create) | **POST** /ad_accounts/{ad_account_id}/product_group_promotions | Create product group promotions
*ProductGroupPromotionsApi* | [**product_group_promotions_update**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionsApi.md#product_group_promotions_update) | **PATCH** /ad_accounts/{ad_account_id}/product_group_promotions | Update product group promotions
*ProductGroupPromotionsApi* | [**product_groups_analytics**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionsApi.md#product_groups_analytics) | **GET** /ad_accounts/{ad_account_id}/product_groups/analytics | Get product group analytics
*ResourcesApi* | [**ad_account_countries_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ResourcesApi.md#ad_account_countries_get) | **GET** /resources/ad_account_countries | Get ad accounts countries
*ResourcesApi* | [**delivery_metrics_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ResourcesApi.md#delivery_metrics_get) | **GET** /resources/delivery_metrics | Get available delivery metrics&#39; definitions
*ResourcesApi* | [**interest_targeting_options_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ResourcesApi.md#interest_targeting_options_get) | **GET** /resources/targeting/interests/{interest_id} | Get interest details
*ResourcesApi* | [**metrics_ready_state_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ResourcesApi.md#metrics_ready_state_get) | **GET** /resources/metrics_ready_state | Get metrics ready state
*ResourcesApi* | [**targeting_options_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ResourcesApi.md#targeting_options_get) | **GET** /resources/targeting/{targeting_type} | Get targeting options
*TermsApi* | [**terms_related_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TermsApi.md#terms_related_list) | **GET** /terms/related | List related terms
*TermsApi* | [**terms_suggested_list**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TermsApi.md#terms_suggested_list) | **GET** /terms/suggested | List suggested terms
*TermsOfServiceApi* | [**terms_of_service_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TermsOfServiceApi.md#terms_of_service_get) | **GET** /ad_accounts/{ad_account_id}/terms_of_service | Get terms of service
*UserAccountApi* | [**user_account_analytics**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/UserAccountApi.md#user_account_analytics) | **GET** /user_account/analytics | Get user account analytics
*UserAccountApi* | [**user_account_analytics_top_pins**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/UserAccountApi.md#user_account_analytics_top_pins) | **GET** /user_account/analytics/top_pins | Get user account top pins analytics
*UserAccountApi* | [**user_account_analytics_top_video_pins**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/UserAccountApi.md#user_account_analytics_top_video_pins) | **GET** /user_account/analytics/top_video_pins | Get user account top video pins analytics
*UserAccountApi* | [**user_account_get**](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/UserAccountApi.md#user_account_get) | **GET** /user_account | Get user account


## Documentation For Models

 - [Account](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Account.md)
 - [ActionType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ActionType.md)
 - [AdAccount](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccount.md)
 - [AdAccountAnalyticsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountAnalyticsResponse.md)
 - [AdAccountCreateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountCreateRequest.md)
 - [AdAccountOwner](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountOwner.md)
 - [AdAccountsCountryResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsCountryResponse.md)
 - [AdAccountsCountryResponseData](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdAccountsCountryResponseData.md)
 - [AdArrayResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdArrayResponse.md)
 - [AdArrayResponseElement](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdArrayResponseElement.md)
 - [AdCommon](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdCommon.md)
 - [AdCreateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdCreateRequest.md)
 - [AdGroupArrayResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupArrayResponse.md)
 - [AdGroupArrayResponseElement](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupArrayResponseElement.md)
 - [AdGroupCommon](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupCommon.md)
 - [AdGroupCreateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupCreateRequest.md)
 - [AdGroupCreateRequestAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupCreateRequestAllOf.md)
 - [AdGroupResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupResponse.md)
 - [AdGroupResponseAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupResponseAllOf.md)
 - [AdGroupSummaryStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupSummaryStatus.md)
 - [AdGroupUpdateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupUpdateRequest.md)
 - [AdGroupUpdateRequestAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupUpdateRequestAllOf.md)
 - [AdGroupsAnalyticsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdGroupsAnalyticsResponse.md)
 - [AdPreviewCreateFromImage](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdPreviewCreateFromImage.md)
 - [AdPreviewCreateFromPin](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdPreviewCreateFromPin.md)
 - [AdPreviewRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdPreviewRequest.md)
 - [AdPreviewURLResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdPreviewURLResponse.md)
 - [AdResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdResponse.md)
 - [AdResponseAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdResponseAllOf.md)
 - [AdUpdateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdUpdateRequest.md)
 - [AdUpdateRequest1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdUpdateRequest1.md)
 - [AdsAnalyticsCreateAsyncRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsCreateAsyncRequest.md)
 - [AdsAnalyticsCreateAsyncRequestAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsCreateAsyncRequestAllOf.md)
 - [AdsAnalyticsCreateAsyncRequestAllOf1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsCreateAsyncRequestAllOf1.md)
 - [AdsAnalyticsCreateAsyncResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsCreateAsyncResponse.md)
 - [AdsAnalyticsFilterColumn](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsFilterColumn.md)
 - [AdsAnalyticsFilterOperator](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsFilterOperator.md)
 - [AdsAnalyticsGetAsyncResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsGetAsyncResponse.md)
 - [AdsAnalyticsMetricsFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsMetricsFilter.md)
 - [AdsAnalyticsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsResponse.md)
 - [AdsAnalyticsTargetingType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AdsAnalyticsTargetingType.md)
 - [AnalyticsMetricsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AnalyticsMetricsResponse.md)
 - [AnalyticsMetricsResponseDailyMetrics](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AnalyticsMetricsResponseDailyMetrics.md)
 - [AnalyticsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AnalyticsResponse.md)
 - [Audience](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Audience.md)
 - [AudienceCommon](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceCommon.md)
 - [AudienceCreateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceCreateRequest.md)
 - [AudienceCreateRequest1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceCreateRequest1.md)
 - [AudienceInsightCategoryCommon](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceInsightCategoryCommon.md)
 - [AudienceRule](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceRule.md)
 - [AudienceType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceType.md)
 - [AudienceUpdateOperationType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceUpdateOperationType.md)
 - [AudienceUpdateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceUpdateRequest.md)
 - [AudienceUpdateRequest1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AudienceUpdateRequest1.md)
 - [AvailabilityFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/AvailabilityFilter.md)
 - [BatchOperation](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BatchOperation.md)
 - [BatchOperationStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BatchOperationStatus.md)
 - [BidFloor](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BidFloor.md)
 - [BidFloorRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BidFloorRequest.md)
 - [BidFloorSpec](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BidFloorSpec.md)
 - [Board](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Board.md)
 - [BoardOwner](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardOwner.md)
 - [BoardSection](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardSection.md)
 - [BoardUpdate](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BoardUpdate.md)
 - [BookClosedResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BookClosedResponse.md)
 - [BrandFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BrandFilter.md)
 - [BudgetType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BudgetType.md)
 - [BulkDownloadRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkDownloadRequest.md)
 - [BulkDownloadRequestCampaignFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkDownloadRequestCampaignFilter.md)
 - [BulkDownloadResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkDownloadResponse.md)
 - [BulkEntityType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkEntityType.md)
 - [BulkOutputFormat](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkOutputFormat.md)
 - [BulkUpsertRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkUpsertRequest.md)
 - [BulkUpsertRequestCreate](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkUpsertRequestCreate.md)
 - [BulkUpsertRequestUpdate](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkUpsertRequestUpdate.md)
 - [BulkUpsertResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkUpsertResponse.md)
 - [BulkUpsertStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkUpsertStatus.md)
 - [BulkUpsertStatusResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/BulkUpsertStatusResponse.md)
 - [CampaignCommon](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCommon.md)
 - [CampaignCreateCommon](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCreateCommon.md)
 - [CampaignCreateCommonAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCreateCommonAllOf.md)
 - [CampaignCreateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCreateRequest.md)
 - [CampaignCreateRequestAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCreateRequestAllOf.md)
 - [CampaignCreateResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCreateResponse.md)
 - [CampaignCreateResponseData](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCreateResponseData.md)
 - [CampaignCreateResponseDataAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCreateResponseDataAllOf.md)
 - [CampaignCreateResponseItem](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignCreateResponseItem.md)
 - [CampaignId](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignId.md)
 - [CampaignResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignResponse.md)
 - [CampaignResponseAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignResponseAllOf.md)
 - [CampaignSummaryStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignSummaryStatus.md)
 - [CampaignUpdateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignUpdateRequest.md)
 - [CampaignUpdateRequestAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignUpdateRequestAllOf.md)
 - [CampaignUpdateResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignUpdateResponse.md)
 - [CampaignsAnalyticsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CampaignsAnalyticsResponse.md)
 - [CatalogsDbItem](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsDbItem.md)
 - [CatalogsFeed](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeed.md)
 - [CatalogsFeedCredentials](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedCredentials.md)
 - [CatalogsFeedIngestionDetails](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedIngestionDetails.md)
 - [CatalogsFeedIngestionErrors](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedIngestionErrors.md)
 - [CatalogsFeedIngestionInfo](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedIngestionInfo.md)
 - [CatalogsFeedProcessingResult](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedProcessingResult.md)
 - [CatalogsFeedProcessingResultFields](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedProcessingResultFields.md)
 - [CatalogsFeedProcessingSchedule](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedProcessingSchedule.md)
 - [CatalogsFeedProcessingStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedProcessingStatus.md)
 - [CatalogsFeedProductCounts](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedProductCounts.md)
 - [CatalogsFeedValidationDetails](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedValidationDetails.md)
 - [CatalogsFeedValidationErrors](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedValidationErrors.md)
 - [CatalogsFeedValidationWarnings](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedValidationWarnings.md)
 - [CatalogsFeedsCreateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedsCreateRequest.md)
 - [CatalogsFeedsUpdateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFeedsUpdateRequest.md)
 - [CatalogsFormat](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsFormat.md)
 - [CatalogsItemValidationDetails](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemValidationDetails.md)
 - [CatalogsItemValidationErrors](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemValidationErrors.md)
 - [CatalogsItemValidationIssue](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemValidationIssue.md)
 - [CatalogsItemValidationIssues](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemValidationIssues.md)
 - [CatalogsItemValidationWarnings](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemValidationWarnings.md)
 - [CatalogsItems](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItems.md)
 - [CatalogsItemsBatch](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemsBatch.md)
 - [CatalogsItemsBatchRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemsBatchRequest.md)
 - [CatalogsItemsCreateBatchRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemsCreateBatchRequest.md)
 - [CatalogsItemsDeleteDiscontinuedBatchRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemsDeleteDiscontinuedBatchRequest.md)
 - [CatalogsItemsUpdateBatchRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsItemsUpdateBatchRequest.md)
 - [CatalogsListProductsByFilterRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsListProductsByFilterRequest.md)
 - [CatalogsListProductsByFilterRequestOneOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsListProductsByFilterRequestOneOf.md)
 - [CatalogsProduct](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProduct.md)
 - [CatalogsProductGroup](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroup.md)
 - [CatalogsProductGroupCreateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupCreateRequest.md)
 - [CatalogsProductGroupCurrencyCriteria](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupCurrencyCriteria.md)
 - [CatalogsProductGroupFeedBasedCase](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupFeedBasedCase.md)
 - [CatalogsProductGroupFilterKeys](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupFilterKeys.md)
 - [CatalogsProductGroupFilters](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupFilters.md)
 - [CatalogsProductGroupFiltersAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupFiltersAllOf.md)
 - [CatalogsProductGroupFiltersAllOfRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupFiltersAllOfRequest.md)
 - [CatalogsProductGroupFiltersAllOfRequestAnyOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupFiltersAllOfRequestAnyOf.md)
 - [CatalogsProductGroupFiltersAllOfRequestAnyOf1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupFiltersAllOfRequestAnyOf1.md)
 - [CatalogsProductGroupFiltersAnyOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupFiltersAnyOf.md)
 - [CatalogsProductGroupMerchantBasedCase](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupMerchantBasedCase.md)
 - [CatalogsProductGroupMultipleStringCriteria](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupMultipleStringCriteria.md)
 - [CatalogsProductGroupMultipleStringListCriteria](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupMultipleStringListCriteria.md)
 - [CatalogsProductGroupPricingCriteria](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupPricingCriteria.md)
 - [CatalogsProductGroupProductCounts](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupProductCounts.md)
 - [CatalogsProductGroupStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupStatus.md)
 - [CatalogsProductGroupType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupType.md)
 - [CatalogsProductGroupUpdateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductGroupUpdateRequest.md)
 - [CatalogsProductMetadata](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsProductMetadata.md)
 - [CatalogsStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CatalogsStatus.md)
 - [ConditionFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConditionFilter.md)
 - [ConversionApiResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionApiResponse.md)
 - [ConversionApiResponseEvents](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionApiResponseEvents.md)
 - [ConversionAttributionWindowDays](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionAttributionWindowDays.md)
 - [ConversionEvents](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEvents.md)
 - [ConversionEventsCustomData](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEventsCustomData.md)
 - [ConversionEventsCustomDataContents](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEventsCustomDataContents.md)
 - [ConversionEventsData](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEventsData.md)
 - [ConversionEventsUserData](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEventsUserData.md)
 - [ConversionEventsUserDataAnyOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEventsUserDataAnyOf.md)
 - [ConversionEventsUserDataAnyOf1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEventsUserDataAnyOf1.md)
 - [ConversionEventsUserDataAnyOf2](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionEventsUserDataAnyOf2.md)
 - [ConversionReportAttributionType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionReportAttributionType.md)
 - [ConversionReportTimeType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ConversionReportTimeType.md)
 - [Country](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Country.md)
 - [CreativeType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CreativeType.md)
 - [Currency](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Currency.md)
 - [CurrencyFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CurrencyFilter.md)
 - [CustomLabel0Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomLabel0Filter.md)
 - [CustomLabel1Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomLabel1Filter.md)
 - [CustomLabel2Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomLabel2Filter.md)
 - [CustomLabel3Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomLabel3Filter.md)
 - [CustomLabel4Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomLabel4Filter.md)
 - [CustomerList](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomerList.md)
 - [CustomerListRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomerListRequest.md)
 - [CustomerListUpdateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/CustomerListUpdateRequest.md)
 - [DataOutputFormat](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/DataOutputFormat.md)
 - [DataStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/DataStatus.md)
 - [DeliveryMetricsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/DeliveryMetricsResponse.md)
 - [DeliveryMetricsResponseItems](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/DeliveryMetricsResponseItems.md)
 - [EntityStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/EntityStatus.md)
 - [Error](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Error.md)
 - [Exception](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Exception.md)
 - [FeedFields](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/FeedFields.md)
 - [GenderFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GenderFilter.md)
 - [GetAudiencesOrderBy](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GetAudiencesOrderBy.md)
 - [GoogleProductCategory0Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GoogleProductCategory0Filter.md)
 - [GoogleProductCategory1Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GoogleProductCategory1Filter.md)
 - [GoogleProductCategory2Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GoogleProductCategory2Filter.md)
 - [GoogleProductCategory3Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GoogleProductCategory3Filter.md)
 - [GoogleProductCategory4Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GoogleProductCategory4Filter.md)
 - [GoogleProductCategory5Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GoogleProductCategory5Filter.md)
 - [GoogleProductCategory6Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/GoogleProductCategory6Filter.md)
 - [Granularity](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Granularity.md)
 - [ImageDetails](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ImageDetails.md)
 - [ImageMetadata](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ImageMetadata.md)
 - [InlineObject](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/InlineObject.md)
 - [ItemAttributes](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemAttributes.md)
 - [ItemAttributesAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemAttributesAllOf.md)
 - [ItemBatchRecord](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemBatchRecord.md)
 - [ItemCreateBatchRecord](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemCreateBatchRecord.md)
 - [ItemDeleteDiscontinuedBatchRecord](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemDeleteDiscontinuedBatchRecord.md)
 - [ItemGroupIdFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemGroupIdFilter.md)
 - [ItemIdFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemIdFilter.md)
 - [ItemProcessingRecord](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemProcessingRecord.md)
 - [ItemProcessingStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemProcessingStatus.md)
 - [ItemResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemResponse.md)
 - [ItemResponseAnyOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemResponseAnyOf.md)
 - [ItemResponseAnyOf1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemResponseAnyOf1.md)
 - [ItemUpdateBatchRecord](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemUpdateBatchRecord.md)
 - [ItemValidationEvent](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ItemValidationEvent.md)
 - [Keyword](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Keyword.md)
 - [KeywordError](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordError.md)
 - [KeywordMetrics](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordMetrics.md)
 - [KeywordMetricsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordMetricsResponse.md)
 - [KeywordUpdate](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordUpdate.md)
 - [KeywordUpdateBody](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordUpdateBody.md)
 - [KeywordsCommon](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordsCommon.md)
 - [KeywordsMetricsArrayResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordsMetricsArrayResponse.md)
 - [KeywordsRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordsRequest.md)
 - [KeywordsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/KeywordsResponse.md)
 - [Language](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Language.md)
 - [LineItem](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/LineItem.md)
 - [MatchType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MatchType.md)
 - [MatchTypeResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MatchTypeResponse.md)
 - [MaxPriceFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MaxPriceFilter.md)
 - [MediaUpload](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaUpload.md)
 - [MediaUploadAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaUploadAllOf.md)
 - [MediaUploadAllOfUploadParameters](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaUploadAllOfUploadParameters.md)
 - [MediaUploadDetails](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaUploadDetails.md)
 - [MediaUploadRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaUploadRequest.md)
 - [MediaUploadStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaUploadStatus.md)
 - [MediaUploadType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MediaUploadType.md)
 - [Metrics](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Metrics.md)
 - [MetricsReportingLevel](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MetricsReportingLevel.md)
 - [MetricsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MetricsResponse.md)
 - [MinPriceFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/MinPriceFilter.md)
 - [NonNullableCatalogsCurrency](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/NonNullableCatalogsCurrency.md)
 - [NonNullableProductAvailabilityType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/NonNullableProductAvailabilityType.md)
 - [NullableCatalogsItemFieldType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/NullableCatalogsItemFieldType.md)
 - [NullableCurrency](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/NullableCurrency.md)
 - [OauthAccessTokenRequestCode](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthAccessTokenRequestCode.md)
 - [OauthAccessTokenRequestCodeAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthAccessTokenRequestCodeAllOf.md)
 - [OauthAccessTokenRequestRefresh](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthAccessTokenRequestRefresh.md)
 - [OauthAccessTokenRequestRefreshAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthAccessTokenRequestRefreshAllOf.md)
 - [OauthAccessTokenResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthAccessTokenResponse.md)
 - [OauthAccessTokenResponseCode](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthAccessTokenResponseCode.md)
 - [OauthAccessTokenResponseCodeAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthAccessTokenResponseCodeAllOf.md)
 - [OauthAccessTokenResponseRefresh](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/OauthAccessTokenResponseRefresh.md)
 - [ObjectiveType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ObjectiveType.md)
 - [PacingDeliveryType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PacingDeliveryType.md)
 - [Paginated](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Paginated.md)
 - [Pin](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/Pin.md)
 - [PinMedia](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMedia.md)
 - [PinMediaMetadata](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaMetadata.md)
 - [PinMediaSource](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaSource.md)
 - [PinMediaSourceImageBase64](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaSourceImageBase64.md)
 - [PinMediaSourceImageURL](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaSourceImageURL.md)
 - [PinMediaSourceVideoID](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaSourceVideoID.md)
 - [PinMediaWithImage](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithImage.md)
 - [PinMediaWithImageAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithImageAllOf.md)
 - [PinMediaWithImageAndVideo](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithImageAndVideo.md)
 - [PinMediaWithImageAndVideoAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithImageAndVideoAllOf.md)
 - [PinMediaWithImages](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithImages.md)
 - [PinMediaWithImagesAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithImagesAllOf.md)
 - [PinMediaWithVideo](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithVideo.md)
 - [PinMediaWithVideoAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithVideoAllOf.md)
 - [PinMediaWithVideos](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithVideos.md)
 - [PinMediaWithVideosAllOf](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinMediaWithVideosAllOf.md)
 - [PinPromotionSummaryStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinPromotionSummaryStatus.md)
 - [PinterestTagEventData](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PinterestTagEventData.md)
 - [PlacementGroupType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/PlacementGroupType.md)
 - [ProductAvailabilityType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductAvailabilityType.md)
 - [ProductGroupAnalyticsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupAnalyticsResponse.md)
 - [ProductGroupPromotion](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotion.md)
 - [ProductGroupPromotionArrayElement](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionArrayElement.md)
 - [ProductGroupPromotionArrayResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionArrayResponse.md)
 - [ProductGroupPromotionCommon](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionCommon.md)
 - [ProductGroupPromotionCreateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionCreateRequest.md)
 - [ProductGroupPromotionUpdateItem](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionUpdateItem.md)
 - [ProductGroupPromotionUpdateRequest](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionUpdateRequest.md)
 - [ProductGroupPromotionUpdateResponseItem](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupPromotionUpdateResponseItem.md)
 - [ProductGroupSummaryStatus](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupSummaryStatus.md)
 - [ProductGroupsCreateRequestFeedBaseCase](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductGroupsCreateRequestFeedBaseCase.md)
 - [ProductType0Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductType0Filter.md)
 - [ProductType1Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductType1Filter.md)
 - [ProductType2Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductType2Filter.md)
 - [ProductType3Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductType3Filter.md)
 - [ProductType4Filter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ProductType4Filter.md)
 - [RelatedTerms](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/RelatedTerms.md)
 - [RelatedTermsRelatedTermsList](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/RelatedTermsRelatedTermsList.md)
 - [ReportingColumnAsync](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/ReportingColumnAsync.md)
 - [SingleInterestTargetingOptionResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/SingleInterestTargetingOptionResponse.md)
 - [TargetingOptionResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TargetingOptionResponse.md)
 - [TargetingSpec](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TargetingSpec.md)
 - [TargetingSpec1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TargetingSpec1.md)
 - [TargetingSpecSHOPPINGRETARGETING](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TargetingSpecSHOPPINGRETARGETING.md)
 - [TargetingSpecSHOPPINGRETARGETING1](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TargetingSpecSHOPPINGRETARGETING1.md)
 - [TargetingTypeFilter](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TargetingTypeFilter.md)
 - [TermsOfService](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TermsOfService.md)
 - [TermsSuggestedResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TermsSuggestedResponse.md)
 - [TopPinsAnalyticsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TopPinsAnalyticsResponse.md)
 - [TopPinsAnalyticsResponseDateAvailability](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TopPinsAnalyticsResponseDateAvailability.md)
 - [TopPinsAnalyticsResponsePins](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TopPinsAnalyticsResponsePins.md)
 - [TopVideoPinsAnalyticsResponse](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TopVideoPinsAnalyticsResponse.md)
 - [TopVideoPinsAnalyticsResponsePins](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TopVideoPinsAnalyticsResponsePins.md)
 - [TrackingUrls](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/TrackingUrls.md)
 - [UpdatableItemAttributes](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/UpdatableItemAttributes.md)
 - [UserListOperationType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/UserListOperationType.md)
 - [UserListType](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/UserListType.md)
 - [VideoMetadata](https://github.com/pinterest/pinterest-python-generated-api-client/blob/main/docs/VideoMetadata.md)


## Documentation For Authorization


## basic

- **Type**: HTTP basic authentication


## conversion_token

- **Type**: Bearer authentication


## pinterest_oauth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://www.pinterest.com/oauth/
- **Scopes**: 
 - **ads:read**: See all of your advertising data, including ads, ad groups, campaigns etc.
 - **ads:write**: Create, update, or delete ads, ad groups, campaigns etc.
 - **boards:read**: See your public boards, including group boards you join
 - **boards:read_secret**: See your secret boards
 - **boards:write**: Create, update, or delete your public boards
 - **boards:write_secret**: Create, update, or delete your secret boards
 - **catalogs:read**: See all of your catalogs data
 - **catalogs:write**: Create, update, or delete your catalogs data
 - **pins:read**: See your public Pins
 - **pins:read_secret**: See your secret Pins
 - **pins:write**: Create, update, or delete your public Pins
 - **pins:write_secret**: Create, update, or delete your secret Pins
 - **user_accounts:read**: See your user accounts


## Author

pinterest-api@pinterest.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in pinterest.generated.client.apis and pinterest.generated.client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from pinterest.generated.client.api.default_api import DefaultApi`
- `from pinterest.generated.client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import pinterest.generated.client
from pinterest.generated.client.apis import *
from pinterest.generated.client.models import *
```
